MethodChannelContinuousSpeechToText class

An implementation of ContinuousSpeechToTextPlatform that uses method channels.

Inheritance

Properties

eventChannel EventChannel
The event channel used to receive speech events from the native platform.
final
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speechEvents Stream<Map<String, dynamic>>
A stream of events from the native speech recognizer.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startListening({String localeId = 'en-IN'}) Future<void>
Starts listening to speech.
override
stopListening() Future<void>
Stops listening to speech.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited