eventChannel property
The event channel used to receive speech events from the native platform.
Implementation
@visibleForTesting
final eventChannel = const EventChannel('continuous_speech_to_text/events');
The event channel used to receive speech events from the native platform.
@visibleForTesting
final eventChannel = const EventChannel('continuous_speech_to_text/events');